import { Status } from './constants';
export interface ApiError {
    code?: number;
    message: string;
    hint?: string;
    stacktrace?: string;
}
export interface Entity {
    eClass?: string;
    id?: string;
    name?: string;
    type?: string;
    status?: Status;
    tags?: string[];
    attributes?: any;
    files?: any[];
    auditEvents?: {
        content?: any;
        report?: string;
        level?: string;
        type?: string;
        [key: string]: any;
    }[];
    notes?: any[];
    [key: string]: any;
}
export interface EntityInfo {
    key?: string;
    entity: Entity;
    [key: string]: any;
}
export interface StepEntityInfo extends EntityInfo {
}
export interface Template extends Entity {
    content: any;
}
export interface WFTemplates {
    targets: Template[];
    dependencies?: Template[];
}
export interface Dataset {
    entities?: Entity[];
    lookups?: any;
    [key: string]: any;
}
export interface WorkflowBuilderHooks {
    [key: string]: Function;
}
export interface DatasetQuery {
    eClass?: string;
    view?: string;
    collection?: string;
    alias?: string;
    entity?: string;
    filters?: Filter[];
    sortings?: Sorting[];
    include?: ('files' | 'notes')[];
    fetch?: number;
    offset?: number;
    operations?: any[];
}
export interface Filter {
    field: string;
    values?: string[];
    value?: any;
    in?: any[] | string;
    op?: 'contains' | 'startswith' | 'endswith' | 'neq' | 'not_in';
}
export interface Sorting {
    field: string;
    direction?: 'asc' | 'desc';
}
export interface View {
    name: string;
    columns: Column[];
    tableCategory: string;
    group: string;
    isEntity: boolean;
}
export interface Column {
    name: string;
    type?: string;
    size?: string;
    isShared?: boolean;
    foreignKeyTo?: string;
    dbType?: string;
    nameLC?: string;
    nameLCF?: string;
    objectKey?: string;
    propertyKey?: string;
    description?: string;
    form?: {
        label: string;
        hide?: boolean;
        options?: string;
        selectOptions?: string[];
        placeholder?: string;
        editor?: string;
        isRequired?: boolean;
        rules?: any[];
        filters?: Filter[];
        sortings?: Sorting[];
        suggestionService?: any;
        dictionary?: {
            type?: string;
            nested?: boolean;
        };
        list?: {
            type?: string;
        };
    };
}
