import { Dataset, Entity, EntityInfo } from '@scifeon/core';
import { NavigationInstruction, RouteConfig } from 'aurelia-router';
import { PLUGIN_TYPE, POSITIONS } from './constants';
export interface Location {
    type?: PLUGIN_TYPE;
    position?: POSITIONS;
    [key: string]: any;
}
export interface Context {
    entity?: Entity;
    position?: POSITIONS;
    [key: string]: any;
}
export interface FileContext extends Context {
    fileInfos: FileInfo[];
}
export interface FileInfo {
    file: File;
    content: string;
    filename: string;
    type: string;
    contentAsBase64?: string;
    wb?: any;
    json?: any;
    csv?: any;
    category?: string;
    [key: string]: any;
}
export interface PageContext {
    params: any;
    routeConfig: RouteConfig;
    navigationInstruction: NavigationInstruction;
}
export interface WidgetContext extends Context {
    header?: string;
    config: any;
    grid: {
        x: number;
        y: number;
        w: number;
        h: number;
    };
}
export interface PluginConfig {
}
export interface PanelConfig extends PluginConfig {
    rank?: number;
}
export interface DashboardPanelConfig extends PanelConfig {
    header?: string;
    width?: number;
    height?: number;
}
export interface ScifeonPlugin {
    [prop: string]: any;
    init?(context: Context, options?: any): any;
    view?(location: Location): string;
    getConfig?(location: Location): PluginConfig;
}
export interface RlsPlugin extends ScifeonPlugin {
    canRead(): boolean;
    canWrite(): boolean;
}
export interface DialogPlugin extends ScifeonPlugin {
}
export interface PagePlugin extends ScifeonPlugin {
    init?(context: PageContext): any;
}
export interface DataLoaderPlugin extends ScifeonPlugin {
    canSave?: boolean;
    init?(context: FileContext): void;
    readFiles?(): void;
    getResult(): Dataset;
    optionsView?(): string;
    entitiesView?(): string;
}
export interface ContentPlugin extends ScifeonPlugin {
}
export interface PanelPlugin extends ScifeonPlugin {
    getConfig?(location: Location): PanelConfig;
    view?(location: Location): string;
}
export interface JsonEditorPlugin extends ScifeonPlugin {
    canSave: boolean;
    renderView?(): string;
    editView?(): string;
}
export interface ListColumnPlugin extends ScifeonPlugin {
    getColumn(): any;
}
export interface SidebarPanelPlugin extends PanelPlugin {
}
export interface DashboardPanelPlugin extends PanelPlugin {
    getConfig?(location: Location): DashboardPanelConfig;
}
export interface EntityPanelPlugin extends PanelPlugin {
}
export interface StepBuilderPlugin extends ScifeonPlugin {
    build(stepInfo: EntityInfo, entityInfos: EntityInfo[]): void;
}
export interface WidgetPlugin extends ScifeonPlugin {
    init?(context: WidgetContext): void;
    view(): string;
    configView?(): string;
    getConfig?(): any;
    defaultConfig?(): {
        size?: {
            minw?: number;
            minh?: number;
        };
        useHeader?: boolean;
        header?: string;
    };
}
